aboutsummaryrefslogtreecommitdiff
path: root/engines/sword2/mouse.cpp
diff options
context:
space:
mode:
authorMax Horn2011-04-14 14:34:28 +0200
committerMax Horn2011-04-14 14:34:28 +0200
commit2e095e25f2435f0d066d2826176e394bda5c4a9c (patch)
tree81d2c4d9e26e4a7644087a13c61b785ae3e431c8 /engines/sword2/mouse.cpp
parent84184aabc00251374a181fe296487619afa779ed (diff)
downloadscummvm-rg350-2e095e25f2435f0d066d2826176e394bda5c4a9c.tar.gz
scummvm-rg350-2e095e25f2435f0d066d2826176e394bda5c4a9c.tar.bz2
scummvm-rg350-2e095e25f2435f0d066d2826176e394bda5c4a9c.zip
ALL: centre -> center
Diffstat (limited to 'engines/sword2/mouse.cpp')
-rw-r--r--engines/sword2/mouse.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/engines/sword2/mouse.cpp b/engines/sword2/mouse.cpp
index d3dcf10f55..b6e9b169c3 100644
--- a/engines/sword2/mouse.cpp
+++ b/engines/sword2/mouse.cpp
@@ -1270,8 +1270,8 @@ void Mouse::createPointerText(uint32 text_id, uint32 pointer_res) {
// Above right
justification = POSITION_AT_LEFT_OF_BASE;
} else {
- // Above centre
- justification = POSITION_AT_CENTRE_OF_BASE;
+ // Above center
+ justification = POSITION_AT_CENTER_OF_BASE;
}
} else if (yOffset > 0) {
// Below pointer
@@ -1282,20 +1282,20 @@ void Mouse::createPointerText(uint32 text_id, uint32 pointer_res) {
// Below right
justification = POSITION_AT_LEFT_OF_TOP;
} else {
- // Below centre
- justification = POSITION_AT_CENTRE_OF_TOP;
+ // Below center
+ justification = POSITION_AT_CENTER_OF_TOP;
}
} else {
// Same y-coord as pointer
if (xOffset < 0) {
- // Centre left
- justification = POSITION_AT_RIGHT_OF_CENTRE;
+ // Center left
+ justification = POSITION_AT_RIGHT_OF_CENTER;
} else if (xOffset > 0) {
- // Centre right
- justification = POSITION_AT_LEFT_OF_CENTRE;
+ // Center right
+ justification = POSITION_AT_LEFT_OF_CENTER;
} else {
- // Centre centre - shouldn't happen anyway!
- justification = POSITION_AT_LEFT_OF_CENTRE;
+ // Center center - shouldn't happen anyway!
+ justification = POSITION_AT_LEFT_OF_CENTER;
}
}